// このファイル（compare.js）をなるべく少ない文字数で書き直してください♪
// main.js でエラーが出なければ（main.js のテストに合格すれば）OK です♪
// このファイル（compare.js）のみ編集可能です♪

/**
 * 2つの画像のどちらがより横長かを比較する
 *
 * img1 よりも img2 のほうが横長 => 負
 * img1 のほうが img2 よりも横長 => 正
 * img1 も img2 も同じくらい横長 => 0
 *
 * @param  {HTMLImageElement} img1
 * @param  {HTMLImageElement} img2
 * @return {number}
 */
export default function compare(img1, img2) {
  //
  // 各画像の幅と高さを変数に格納しておく
  //
  const w1 = img1.naturalWidth;
  const h1 = img1.naturalHeight;

  const w2 = img2.naturalWidth;
  const h2 = img2.naturalHeight;

  //
  // 方針：
  // ① まずは幅をチェックする
  // ② つぎに高さをチェックする
  //

  //
  // w1 < w2、
  // つまり、
  // img1 よりも img2 のほうが幅が広い時
  // img1 よりも img2 のほうが横長？？？
  //
  if (w1 < w2) {
    // h1 < h2、
    // つまり img1 よりも img2 のほうが高さが（も）高いなら
    // 結果が逆転する可能性がある
    if (h1 < h2) {
      const rw = w2 / w1; // 幅がどれだけ差があるか
      const rh = h2 / h1; // 高さがどれだけ差があるか

      // 高さの影響が大きい場合
      if (rw < rh) {
        return 1;

      // 幅の影響が大きい場合
      } else if (rw > rh) {
        return -1;

      // どちらも同じの場合
      // w1 < w2 の横長具合への影響は影響は相殺される
      } else {
        return 0;
      }

    // h1 > h2 なら
    // img1 はより縦長に、img2 はより横長にしかなり得ないので
    // img1 よりも img2 のほうが横長であることが確定する
    } else if (h1 > h2) {
      return -1;

    // 高さが同じなら
    // img1 よりも img2 のほうが横長であることが確定する
    } else {
      return -1;
    }

  //
  // w1 > w2 つまり、
  // img1 のほうが img2 よりも幅が広い時
  // img1 のほうが img2 よりも横長？？？
  //
  } else if (w1 > w2) {
    // h1 < h2 なら
    // img1 はより横長に、img2 はより縦長にしかなり得ないので
    // img1 のほうが img2 よりも横長であることが確定する
    if (h1 < h2) {
      return 1;

    // h1 > h2 なら
    // 結果が逆転する可能性がある
    } else if (h1 > h2) {
      const rw = w1 / w2; // 幅がどれだけ差があるか
      const rh = h1 / h2; // 高さがどれだけ差があるか

      // 高さの影響が大きい場合
      if (rw < rh) {
        return -1;

      // 幅の影響が大きい場合
      } else if (rw > rh) {
        return 1;

      // どちらも同じの場合
      // w1 > w2 の横長具合への影響は影響は相殺される
      } else {
        return 0;
      }

    // 高さが同じなら
    // img1 のほうが img2 よりも横長であることが確定する
    } else {
      return 1;
    }

  //
  // 幅が同じ場合は、高さだけで結果が決まる
  //
  } else {
    // img1 のほうが img2 よりも横長
    if (h1 < h2) {
      return 1;

    // img1 よりも img2 のほうが横長
    } else if (h1 > h2) {
      return -1;

    // img1 も img2 も同じくらい横長
    } else {
      return 0;
    }
  }
}
